@@ -5,6 +5,7 @@
  *
  * Copyright 2002 Darren Bounds <dbounds@intrusense.com>
  * Copyright 2017 Sharad B
+ * Copyright 2020 Jeroen Roovers <jer@gentoo.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,12 +31,12 @@
 #define READ_TIMEOUT                    500
 #define SNAPLEN_DEFAULT                 68
 
-u_int16_t g_display;
-u_int16_t g_link_layer;
-u_int16_t g_dump_pkt;
-u_int16_t g_time_gmt;
-u_int16_t g_t_rst;
-u_int16_t g_snap_len;
-u_int32_t g_pkt_rst;
+extern u_int16_t g_display;
+extern u_int16_t g_link_layer;
+extern u_int16_t g_dump_pkt;
+extern u_int16_t g_time_gmt;
+extern u_int16_t g_t_rst;
+extern u_int16_t g_snap_len;
+extern u_int32_t g_pkt_rst;
 
 #endif /* __CAPTURE_DEFS_H */
