@@ -5,6 +5,7 @@
  *
  * Copyright 2002 Darren Bounds <dbounds@intrusense.com>
  * Copyright 2016 Robert Krause <ruport@f00l.de>
+ * Copyright 2020 Jeroen Roovers <jer@gentoo.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,7 +34,7 @@
 #define SUCCESS           		1
 #define FAILURE           		-1
 
-char error_buf[ERRBUF_MAXLEN];
+extern char error_buf[ERRBUF_MAXLEN];
 
 void fatal_error(char *,...);
 
