@@ -7,6 +7,7 @@
  * Copyright 2007      Kumar Appaiah <akumar@ee.iitm.ac.in>
  * Copyright 2016-2017 Robert Krause <ruport@f00l.de>
  * Copyright 2017      Sharad B
+ * Copyright 2020      Jeroen Roovers <jer@gentoo.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -138,20 +139,20 @@
 #define P_INT64                         0x7FFFFFFFFFFFFFFF
 #define P_UINT64                        0xFFFFFFFFFFFFFFFF
 
-char g_w_file[OPT_MAXLEN];
-char g_r_file[OPT_MAXLEN];
+extern char g_w_file[OPT_MAXLEN];
+extern char g_r_file[OPT_MAXLEN];
 
-pcap_t *g_pkt;
-u_int8_t g_tr_fin;
-char *g_filter;
-char *g_device;
-u_int16_t g_hdr_len;
-u_int16_t g_pkt_len;
-u_int16_t g_verbose;
-u_int16_t g_resolve;
-u_int16_t g_p_mode;
-u_int64_t g_cnt;
-u_int64_t g_inj_cnt;
-u_int64_t g_cap_cnt;
+extern pcap_t *g_pkt;
+extern u_int8_t g_tr_fin;
+extern char *g_filter;
+extern char *g_device;
+extern u_int16_t g_hdr_len;
+extern u_int16_t g_pkt_len;
+extern u_int16_t g_verbose;
+extern u_int16_t g_resolve;
+extern u_int16_t g_p_mode;
+extern u_int64_t g_cnt;
+extern u_int64_t g_inj_cnt;
+extern u_int64_t g_cap_cnt;
 
 #endif /* __GLOBALS_H */
