@@ -4,11 +4,13 @@
  * Original author: Darren Bounds <dbounds@intrusense.com>
  *
  * Copyright 2002-2004 Darren Bounds <dbounds@intrusense.com>
- * Copyright 2005      Dennis Vshivkov <walrus@amur.ru>
+ * Copyright 2004-2005 Dennis Vshivkov <walrus@amur.ru>
  * Copyright 2006      Deniz Adrian <adrian@netzquadrat.de>
  * Copyright 2013      Mats Erik Andersson <gnu@gisladisker.se>
  * Copyright 2017      Robert Krause <ruport@f00l.de>
  * Copyright 2017      Sharad B
+ * Copyright 2020      David Polverari <david.polverari@gmail.com>
+ * Copyright 2020      Jeroen Roovers <jer@gentoo.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +32,78 @@
 
 #include "main.h"
 
+char g_w_file[OPT_MAXLEN];
+char g_r_file[OPT_MAXLEN];
+
+pcap_t *g_pkt;
+u_int8_t g_tr_fin;
+char *g_filter;
+char *g_device;
+u_int16_t g_hdr_len;
+u_int16_t g_pkt_len;
+u_int16_t g_verbose;
+u_int16_t g_resolve;
+u_int16_t g_p_mode;
+u_int64_t g_cnt;
+u_int64_t g_inj_cnt;
+u_int64_t g_cap_cnt;
+
+/* capture_defs.h */
+u_int16_t g_display;
+u_int16_t g_link_layer;
+u_int16_t g_dump_pkt;
+u_int16_t g_time_gmt;
+u_int16_t g_t_rst;
+u_int16_t g_snap_len;
+u_int32_t g_pkt_rst;
+
+/* inject_defs.h */
+u_int16_t g_init_type;
+u_int16_t g_rand_d_port;
+u_int16_t g_rand_s_port;
+u_int16_t g_s_port;
+u_int16_t g_d_port;
+u_int16_t g_port_range;
+u_int16_t g_interval_sec;
+u_int16_t g_interval_usec;
+u_int16_t g_injection_type;
+u_int16_t g_r_timeout;
+u_int16_t g_burst_rate;
+u_int16_t g_payload_len;
+u_int8_t *g_payload;
+u_int8_t g_hex_payload;
+u_int8_t *g_s_d_port;
+u_int8_t g_hwaddr_p[18];
+u_int8_t g_rawip;
+
+struct timeval g_bf_pcap;
+struct timeval g_af_pcap;
+
+struct arphdr_opts g_ahdr_o;
+struct enethdr_opts g_ehdr_o;
+struct icmp4hdr_opts g_i4hdr_o;
+struct ip4hdr_opts g_ip4hdr_o;
+struct tcphdr_opts g_thdr_o;
+struct udphdr_opts g_uhdr_o;
+
+libnet_t *g_pkt_d;
+
+static void
+randomisable_str(u_int8_t **to, u_int16_t *rand, size_t size, const char *desc)
+{
+    if (strcmp(optarg, "R") != 0)
+    {
+	if ((*to = strdup(optarg)) == NULL)
+	    fatal_error("Memory unavailable for: %s", optarg);
+    }
+    else
+    {
+	*rand = 1;
+	if ((*to = malloc(size)) == NULL)
+	    fatal_error("Memory unavailable for: %s", desc);
+    }
+}
+
 void
 parse_capture_options(int argc, char *argv[])
 {
@@ -256,12 +330,7 @@ parse_inject:
                 break;
 
             case 'd':
-	        if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_ip4hdr_o.rand_d_addr = 1;
-
-		if(!(g_ip4hdr_o.d_addr = (u_int8_t*)strdup(optarg)))
-		    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_ip4hdr_o.d_addr, &g_ip4hdr_o.rand_d_addr, 16, "destination IP");
                 break;
 
             case 'D':
@@ -275,15 +344,10 @@ parse_inject:
 
             case 'e':
 #ifdef MACOS
-            fprintf(stderr, "\nWarning: You cannot specify an ethernet address on this operating system.\n");
-	    break;
+                fprintf(stderr, "\nWarning: You cannot specify an ethernet address on this operating system.\n");
+                break;
 #endif
-		if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_ehdr_o.rand_s_addr = 1;
-
-      		if(!(g_ehdr_o.s_addr = (u_int8_t*)strdup(optarg)))
-		    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_ehdr_o.s_addr, &g_ehdr_o.rand_s_addr, 18, "source MAC");
                 g_init_type = 0;
                 g_link_layer = 1;
                 break;
@@ -291,14 +355,9 @@ parse_inject:
             case 'E':
 #ifdef MACOS
                 fprintf(stderr, "\nWarning: You cannot specify an ethernet address on this operating system.\n");
-		break;
+                break;
 #endif
-                if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_ehdr_o.rand_d_addr = 1;
-
-                if(!(g_ehdr_o.d_addr = (u_int8_t*)strdup(optarg)))
-		    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_ehdr_o.d_addr, &g_ehdr_o.rand_d_addr, 18, "destination MAC");
                 g_init_type = 0;
                 g_link_layer = 1;
                 break;
@@ -329,12 +388,7 @@ parse_inject:
                 break;
 
             case 'g':
-                if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_i4hdr_o.rand_gw = 1;
-
-                if(!(g_i4hdr_o.gw = (u_int8_t*)strdup(optarg)))
-                    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_i4hdr_o.gw, &g_i4hdr_o.rand_gw, 16, "gateway IP");
                 break;
 
             case 'G':
@@ -360,12 +414,7 @@ parse_inject:
                 break;
 
             case 'j':
-                if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_i4hdr_o.rand_orig_s_addr = 1;
-
-                if(!(g_i4hdr_o.orig_s_addr = (u_int8_t*)strdup(optarg)))
-                    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_i4hdr_o.orig_s_addr, &g_i4hdr_o.rand_orig_s_addr, 16, "original source IP");
                 break;
 
             case 'J':
@@ -385,12 +434,7 @@ parse_inject:
                 break;
 
             case 'l':
-                if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_i4hdr_o.rand_orig_d_addr = 1;
-
-                if(!(g_i4hdr_o.orig_d_addr = (u_int8_t*)strdup(optarg)))
-                    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_i4hdr_o.orig_d_addr, &g_i4hdr_o.rand_orig_d_addr, 16, "original destination IP");
                 break;
 
             case 'L':
@@ -472,11 +516,7 @@ parse_inject:
                 break;
 
             case 's':
-                if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_ip4hdr_o.rand_s_addr = 1;
-
-                if(!(g_ip4hdr_o.s_addr = (u_int8_t*)strdup(optarg)))
-		    fatal_error("Memory unavailable for: %s", optarg);
+                randomisable_str(&g_ip4hdr_o.s_addr, &g_ip4hdr_o.rand_s_addr, 16, "source IP");
                 break;
 
             case 'S':
@@ -524,39 +564,19 @@ parse_inject:
                 break;
 
             case 'x':
-                if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_ahdr_o.rand_s_paddr = 1;
-
-                if(!(g_ahdr_o.s_paddr = (u_int8_t*)strdup(optarg)))
-                    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_ahdr_o.s_paddr, &g_ahdr_o.rand_s_paddr, 16, "ARP sender IP");
                 break;
 
             case 'X':
-                if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_ahdr_o.rand_s_eaddr = 1;
-
-                if(!(g_ahdr_o.s_eaddr = (u_int8_t*)strdup(optarg)))
-                    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_ahdr_o.s_eaddr, &g_ahdr_o.rand_s_eaddr, 18, "ARP sender MAC");
                 break;
 
             case 'y':
-                if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_ahdr_o.rand_r_paddr = 1;
-
-                if(!(g_ahdr_o.r_paddr = (u_int8_t*)strdup(optarg)))
-                    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_ahdr_o.r_paddr, &g_ahdr_o.rand_r_paddr, 16, "ARP receiver IP");
                 break;
 
             case 'Y':
-                if(strlen(optarg) == 1 && !strncmp(optarg, "R", 1))
-                    g_ahdr_o.rand_r_eaddr = 1;
-
-                if(!(g_ahdr_o.r_eaddr = (u_int8_t*)strdup(optarg)))
-                    fatal_error("Memory unavailable for: %s", optarg);
-
+                randomisable_str(&g_ahdr_o.r_eaddr, &g_ahdr_o.rand_r_eaddr, 18, "ARP receiver MAC");
                 break;
 
             case 'z':
